==> OpenPatricianModel-0.8.0-RC1-sources.jar: ch/sahits/game/openpatrician/model/sea/TravellingVessel.java <==
package ch.sahits.game.openpatrician.model.sea;

import ch.sahits.game.openpatrician.annotation.ClassCategory;
import ch.sahits.game.openpatrician.annotation.EClassCategory;
import ch.sahits.game.openpatrician.annotation.ListType;
import ch.sahits.game.openpatrician.model.ship.INavigableVessel;
import javafx.beans.property.DoubleProperty;
import javafx.beans.property.SimpleDoubleProperty;
import javafx.geometry.Point2D;
import javafx.scene.shape.Path;
import lombok.Getter;
import lombok.RequiredArgsConstructor;
import lombok.Setter;

import java.util.List;

/**
 * @author Andi Hotz, (c) Sahits GmbH, 2016
 *         Created on Jan 08, 2016
 */
@RequiredArgsConstructor
@Getter
@Setter
@ClassCategory(EClassCategory.DEPENDS_ON_SERIALIZED_BEAN)
public class TravellingVessel {
    private final INavigableVessel vessel;
    /** Path that can be used to display on the map. This path is smoothed. */
    private Path drwawablePath;

    /**
     * List of points representing the path. This list is used to calculate
     * the position of the vessel.
     */
    @ListType(Point2D.class)
    private List<Point2D> calculatablePath;
    /**
     * Value between 0 and 1 indicating the position of the path.
     */
    private DoubleProperty positionOnPath = new SimpleDoubleProperty(0);

    public DoubleProperty positionOnPathProperty() {
        return positionOnPath;
    }

    public void setPositionOnPath(double positionOnPath) {
        this.positionOnPath.set(positionOnPath);
    }


    public double getPositionOnPath() {
        return positionOnPath.get();
    }

}

==> OpenPatricianModel-0.9.0-RC1-sources.jar: ch/sahits/game/openpatrician/model/sea/TravellingVessel.java <==
package ch.sahits.game.openpatrician.model.sea;

import ch.sahits.game.openpatrician.utilities.annotation.ClassCategory;
import ch.sahits.game.openpatrician.utilities.annotation.EClassCategory;
import ch.sahits.game.openpatrician.utilities.annotation.ListType;
import ch.sahits.game.openpatrician.model.ship.INavigableVessel;
import javafx.beans.property.DoubleProperty;
import javafx.beans.property.SimpleDoubleProperty;
import javafx.geometry.Point2D;
import javafx.scene.shape.Path;
import lombok.Getter;
import lombok.RequiredArgsConstructor;
import lombok.Setter;

import java.util.List;

/**
 * @author Andi Hotz, (c) Sahits GmbH, 2016
 *         Created on Jan 08, 2016
 */
@RequiredArgsConstructor
@Getter
@Setter
@ClassCategory(EClassCategory.DEPENDS_ON_SERIALIZED_BEAN)
public class TravellingVessel {
    private final INavigableVessel vessel;
    /** Path that can be used to display on the map. This path is smoothed. */
    private Path drwawablePath;

    /**
     * List of points representing the path. This list is used to calculate
     * the position of the vessel.
     */
    @ListType(Point2D.class)
    private List<Point2D> calculatablePath;
    /**
     * Value between 0 and 1 indicating the position of the path.
     */
    private DoubleProperty positionOnPath = new SimpleDoubleProperty(0);

    public DoubleProperty positionOnPathProperty() {
        return positionOnPath;
    }

    public void setPositionOnPath(double positionOnPath) {
        this.positionOnPath.set(positionOnPath);
    }


    public double getPositionOnPath() {
        return positionOnPath.get();
    }

}
